@@ -1,4 +1,4 @@
-#ident "@(#)do_chat.c	3.3 96/03/03 Copyright (c) Gert Doering"
+#ident "$Id: do_chat.c,v 4.1 1997/01/12 14:53:37 gert Exp $ Copyright (c) Gert Doering"
 
 /* do_chat.c
  *
@@ -23,7 +23,7 @@
 #include "tio.h"
 
 boolean chat_has_timeout;
-static RETSIGTYPE chat_timeout()
+static RETSIGTYPE chat_timeout(SIG_HDLR_ARGS)
 {
     chat_has_timeout = TRUE;
 }
