@@ -1,4 +1,4 @@
-#ident "$Id: faxlib.c,v 4.36 1998/06/20 15:58:13 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.44 1999/06/15 20:53:53 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
@@ -51,8 +51,7 @@ int w = 0;
 
     while ( *id && w < sizeof(fax_remote_id)-1 )
     {
-        if ( *id == '"' || *id == '\'' ) fax_remote_id[w++] = '_';
-                                    else fax_remote_id[w++] = *id;
+        if ( *id != '"' && *id != '\'' ) fax_remote_id[w++] = *id;
         id++;
     }
     fax_remote_id[w]=0;
@@ -601,6 +600,11 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_class2_0;
 	    mis = mdm_get_idstring( "ATI1", 2, fd );
 	    break;
+	  case 33604:
+	    lprintf( L_MESG, "ZyXEL U-336E detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI1", 2, fd );
+	    break;
 	  case 1281:
 	  case 1291:
 	  case 1292:
@@ -645,11 +649,23 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_quirks |= MQ_NEED2;
 	    mis = mdm_get_idstring( "ATI9", 1, fd );
 	    break;
+          case 932:	/* Thomas Schuett, info@thomas-schuett.de */
+	    lprintf( L_MESG, "Zoom MX/S detected" );
+	    modem_type=Mt_class2;
+	    modem_quirks |= MQ_NEED2;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	    break;	      
 	  case 961:
 	    lprintf( L_MESG, "Zoltrix 14400 faxmodem detected (?)" );
 	    modem_type=Mt_class2;
 	    mis = mdm_get_idstring( "ATI4", 1, fd );
 	    break;
+	  case 144:     /* UMC 1440 baud modem (not sure) */
+	    lprintf( L_MESG, "UMC92144EF modem detected(?)" );
+	    modem_type=Mt_class2;
+	    mis = mdm_get_idstring( "ATI4", 1, fd );
+	    modem_quirks |= MQ_NEED2;
+	    break;
 	  case 184:	/* sure? */
 	    lprintf( L_MESG, "Telebit FastBlazer detected" );
 	    modem_type=Mt_data;
@@ -684,7 +700,12 @@ int mdm_identify _P1( (fd), int fd )
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	    break;
 	  case 282:	/* ATI6/ATI3 for model/firmware info */
-	    lprintf( L_MESG, "ELSA MicroLink 28.8 TQV detected" );
+	    lprintf( L_MESG, "ELSA MicroLink 28.8/56K series detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	    break;
+	  case 140:	/* ATI6/ATI3 for model/firmware info */
+	    lprintf( L_MESG, "ELSA MicroLink 14.4TQ series detected" );
 	    modem_type=Mt_class2_0;
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	    break;
@@ -754,6 +775,22 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_unknown;
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	}
+	/* got this from Andreas Muck, <andi@koala.rhein-neckar.de>
+	 * and Frank Damgaard <frda@post3.tele.dk>
+	 */
+	else if ( strncmp( l, "5607A", 5 ) == 0 ||
+	          strncmp( l, "5607B", 5 ) == 0 )
+	{
+	    lprintf( L_MESG, "USR Courier/Sportster V90 (national variant?) detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	}
+	/* grrr, another one of those - Bill Nugent <whn@topelo.lopi.com> */
+	else if ( strncmp( l, "MT5600ZDXV", 10 ) == 0 )
+	{
+	    lprintf( L_MESG, "Multitech MT5600ZDXV detected" );
+	    modem_type=Mt_class2;
+	}
     }
 
     if ( mis != NULL ) 
