@@ -1,4 +1,4 @@
-#ident "@(#)getdisk.c @(#)getdisk.c	3.2 95/11/24 Copyright (c) 1994 Elegant Communications Inc."
+#ident "@(#)getdisk.c $Id: getdisk.c,v 4.1 1997/01/12 14:53:39 gert Exp $ Copyright (c) 1994 Elegant Communications Inc."
 
 /*
 
@@ -113,7 +113,7 @@
 #endif
 
 #ifdef HASDISKSTAT
-# if !defined(vsnxdyn) && !defined(vdomain)
+# if !defined(vsnxdyn) && !defined(vdomain) && !defined(_AIX)
 #  include <sys/types.h>
 #  include <sys/param.h>
 #  include <sys/mount.h>
