@@ -1,4 +1,4 @@
-#ident "$Id: login.c,v 4.6 1998/07/05 21:11:24 gert Exp $ Copyright (C) 1993 Gert Doering"
+#ident "$Id: login.c,v 4.10 1999/05/24 13:35:31 gert Exp $ Copyright (C) 1993 Gert Doering"
 
 
 /* login.c
@@ -103,16 +103,16 @@ boolean match _P2( (user,key), char * user, char * key )
  * does *NOT* return
  */
 
-void login_dispatch _P2( (user, is_callback ),  
-			 char * user, boolean is_callback )
+void login_dispatch _P3( (user, is_callback, cfg_file ),  
+			 char * user, boolean is_callback, char * cfg_file )
 {
-    char * argv[10];
+#define MAX_LOGIN_ARGS 9
+    char * argv[MAX_LOGIN_ARGS+1];
     int	argc = 0;
     char * cmd = NULL;
     int i;
 
-    /* read "mgetty.login" config file */
-#ifdef LOGIN_CFG_FILE
+    /* read "mgetty.login" config file (if specified) */
     FILE * fp = NULL;
     int file_version = 1;		/* login.config format changed! */
     char * line, * key, *p;
@@ -121,7 +121,13 @@ void login_dispatch _P2( (user, is_callback ),
 
     struct stat st;
 
-    char * cfg_file = makepath( LOGIN_CFG_FILE, CONFDIR );
+    if ( cfg_file == NULL ) 
+    {
+	lprintf( L_JUNK, "login: no login cfg file defined" );
+	goto fallthrough;
+    }
+
+    cfg_file = _makepath( cfg_file, CONFDIR );
 
     lprintf( L_JUNK, "login: use login config file %s", cfg_file );
     
@@ -133,15 +139,19 @@ void login_dispatch _P2( (user, is_callback ),
     if ( stat( cfg_file, &st ) < 0 )
     {
 	lprintf( L_ERROR, "login: stat('%s') failed", cfg_file );
+	goto fallthrough;
     }
-    else	/* permission check */
-      if ( st.st_uid != 0 || ( ( st.st_mode & 0077 ) != 0 ) )
+
+    /* permission check */
+    if ( st.st_uid != 0 || ( ( st.st_mode & 0077 ) != 0 ) )
     {
 	errno=EINVAL;
 	lprintf( L_FATAL, "login: '%s' must be root/0600", cfg_file );
+	goto fallthrough;
     }
-    else
-      if ( (fp = fopen( cfg_file, "r" )) == NULL )
+
+    /* go for it! */
+    if ( (fp = fopen( cfg_file, "r" )) == NULL )
     {
 	lprintf( L_FATAL, "login: cannot open %s", cfg_file );
     }
@@ -276,7 +286,7 @@ void login_dispatch _P2( (user, is_callback ),
 	    
 	    argc = 1;
 	    p = strtok( NULL, " \t" );
-	    while ( argc < 9 && p != NULL )
+	    while ( argc < MAX_LOGIN_ARGS && p != NULL )
 	    {
 		if ( strcmp( p, "@" ) == 0 )		/* user name */
 		{
@@ -295,15 +305,16 @@ void login_dispatch _P2( (user, is_callback ),
 		p = strtok( NULL, " \t" );
 	    }
 
+	    if ( p != NULL )			/* arguments left? */
+		lprintf( L_WARN, "login.config: max. %d command line arguments possible", MAX_LOGIN_ARGS );
+
 	    break;
 	}		/* end if (matching line found) */
     }	/* end while( not end of config file ) */
 
     if ( fp != NULL ) fclose( fp );
 
-#else	/* !LOGIN_CFG_FILE */
-    lprintf( L_JUNK, "login: no login cfg file defined" );
-#endif	/* LOGIN_CFG_FILE */
+fallthrough:
 
     /* default to "/bin/login <user>" */
     if ( argc == 0 )
@@ -338,8 +349,7 @@ void login_dispatch _P2( (user, is_callback ),
      * logins, like Fido and AutoPPP, because /bin/login reconstructs its
      * environment from scratch) - not general enough, though.
      */
-    set_env_var( "CALLER_ID", CallerId );
-    set_env_var( "CONNECT", Connect );
+    setup_environment();
 
     /* execute login */
     execv( cmd, argv );
@@ -349,3 +359,10 @@ void login_dispatch _P2( (user, is_callback ),
     lprintf( L_FATAL, "cannot execute '%s'", cmd );
     exit(FAIL);
 }
+
+void setup_environment _P0(void)
+{
+    set_env_var( "CALLER_ID", CallerId );
+    set_env_var( "CALLED_ID", CalledNr );
+    set_env_var( "CONNECT", Connect );
+}
