@@ -1,4 +1,4 @@
-#ident "$Id: mgetty.c,v 4.23 1998/09/01 11:14:45 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.c,v 4.27 1999/06/01 14:52:11 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.c
  *
@@ -414,9 +414,10 @@ int main _P2((argc, argv), int argc, char ** argv)
     if ( c_isset(port_mode) ) 
 	chmod( devname, c_int(port_mode) );
 
-    /* if necessary, kill any dangling processes (Marc Boucher) */
-#if defined( EXEC_FUSER ) && ! ( defined(M_UNIX) || defined(sunos4) || \
-				 defined(linux) )
+    /* if necessary, kill any processes that still has the serial device 
+     * open (Marc Boucher, Marc Schaefer).
+     */
+#if defined( EXEC_FUSER )
     sprintf( buf, EXEC_FUSER, devname );
     if ( ( i = system( buf ) ) != 0 )
         lprintf( L_WARN, "%s: return code %d", buf, i );
@@ -452,7 +453,7 @@ int main _P2((argc, argv), int argc, char ** argv)
     else
     {
 	/* initialize data part */
-	if ( mg_init_data( STDIN, c_chat(init_chat),
+	if ( mg_init_data( STDIN, c_chat(init_chat), c_bool(need_dsr),
 	                          c_chat(force_init_chat) ) == FAIL )
 	{
 	    lprintf( L_AUDIT, "failed in mg_init_data, dev=%s, pid=%d",
@@ -762,7 +763,8 @@ Ring_got_action:
 		if ( c_bool(ringback) )
 		    lprintf( L_AUDIT, "missed ringback!" );
 		else
-		    lprintf( L_AUDIT, "phone stopped ringing (rings=%d)", rings );
+		    lprintf( L_AUDIT, "phone stopped ringing (rings=%d, dev=%s, pid=%d, caller='%s')", rings, Device, getpid(), CallerId );
+
 		mgetty_state = St_go_to_jail;
 		break;
 	      case A_CONN:		/* CONNECT */
@@ -1055,7 +1057,8 @@ Ring_got_action:
 	}
 
 	/* hand off to login dispatcher (which will call /bin/login) */
-	login_dispatch( buf, mgetty_state == St_callback_login? TRUE: FALSE);
+	login_dispatch( buf, mgetty_state == St_callback_login? TRUE: FALSE,
+			c_string(login_config) );
 
 	/* doesn't return, if it does, something broke */
 	exit(FAIL);
