@@ -1,7 +1,7 @@
 #ifndef ___MGETTY_H
 #define ___MGETTY_H
 
-#ident "$Id: mgetty.h,v 4.13 1998/09/11 10:45:07 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.h,v 4.17 1999/05/24 13:35:06 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.h
  *
@@ -226,7 +226,8 @@ void	faxlib_init _PROTO((void));
 extern	int modem_quirks;
 
 /* initialization stuff: mg_m_init.c */
-int	mg_init_data  _PROTO(( int fd, char * chat_seq[], char * force_seq[]));
+int	mg_init_data  _PROTO(( int fd, char * chat_seq[], 
+			       boolean need_dsr, char * force_seq[]));
 int	mg_init_fax   _PROTO(( int fd, char * mclass, char * fax_id, 
 			       boolean fax_only, int fax_max_speed ));
 int 	mg_init_voice _PROTO(( int fd ));
@@ -253,7 +254,8 @@ char *	ln_escape_prompt _PROTO(( char * prompt ));
 void	set_env_var _PROTO(( char * var, char * string ));
 
 /* login stuff */
-void login_dispatch _PROTO(( char * user, boolean is_callback ));
+void login_dispatch _PROTO(( char * user, boolean is_callback, char * cf));
+void setup_environment _PROTO(( void ));
 
 /* how long should I wait for a string from modem */
 #define FAX_RESPONSE_TIMEOUT	120
@@ -320,4 +322,15 @@ extern char *	optarg;
  char * strdup _PROTO(( char *src ));
 #endif
 
+/* hardware handshake flags for tio.c/tio.h
+ * we have to define them here, because otherwise config.c would break
+ */
+#define FLOW_NONE	0x00
+#define FLOW_HARD	0x01		/* rts/cts */
+#define FLOW_XON_IN	0x02		/* incoming data, send xon/xoff */
+#define FLOW_XON_OUT	0x04		/* send data, honor xon/xoff */
+#define FLOW_SOFT	(FLOW_XON_IN | FLOW_XON_OUT)
+#define FLOW_BOTH	(FLOW_HARD | FLOW_SOFT )
+#define FLOW_XON_IXANY	0x08		/* set IXANY flag together with IXON */
+
 #endif			/* ___MGETTY_H */
