@@ -1,4 +1,4 @@
-#ident "@(#)tio.c	3.10 96/10/16 Copyright (c) 1993 Gert Doering"
+#ident "$Id: tio.c,v 4.3 1998/01/20 10:40:46 gert Exp $ Copyright (c) 1993 Gert Doering"
 
 /* tio.c
  *
@@ -10,8 +10,7 @@
 #include <sys/types.h>
 #include <errno.h>
 
-#if defined(_AIX) || defined(NeXT)
-#include <sys/ioctl.h>
+#ifdef NeXT
 #include <sys/file.h>
 #endif
 
@@ -115,6 +114,9 @@ static struct	speedtab {
 #ifdef	B57600
 	{ B57600, 57600, "57600" },
 #endif
+#ifdef	B76800
+	{ B76800, 76800, "76800" },
+#endif
 #ifdef	B115200
 	{ B115200,115200,"115200"},
 #endif
@@ -553,6 +555,8 @@ int tio_set_flow_control _P3( (fd, t, type), int fd, TIO * t, int type )
 
     /* SVR4 came up with a new method of setting h/w flow control */
 #ifdef USE_TERMIOX
+    lprintf( L_NOISE, "tio_set_flow_control: using termiox" );
+
     if (ioctl(fd, TCGETX, &tix) < 0)
     {
 	lprintf( L_ERROR, "ioctl TCGETX" ); return ERROR;
@@ -567,11 +571,17 @@ int tio_set_flow_control _P3( (fd, t, type), int fd, TIO * t, int type )
 	lprintf( L_ERROR, "ioctl TCSETX" ); return ERROR;
     }
 #endif
-    /* AIX has yet another method to set hardware flow control (yuck!) */
-#ifdef _AIX
+    /* AIX has yet another method to set hardware flow control
+     * interesting enough, in AIX 4, this ioctl still exists but doesn't
+     * work anymore -- instead, they have adopted termiox. *bah*
+     */
+#if defined(_AIX) && !defined(USE_TERMIOX)
+    lprintf( L_NOISE, "tio_set_flow_control: using TXADDCD" );
+
     if ( ioctl( fd, ( type & FLOW_HARD ) ? TXADDCD : TXDELCD, "rts" ) < 0 )
     {
-	lprintf( L_ERROR, "ioctl TXADDCD/TXDELCD" ); return ERROR;
+	lprintf( L_NOISE, "ioctl TXADDCD/TXDELCD failed, errno=%d", errno);
+	return ERROR;
     }
 #ifdef DEBUG
     {	union txname t; int i;
@@ -597,6 +607,8 @@ int tio_set_flow_control _P3( (fd, t, type), int fd, TIO * t, int type )
  * details.
  */
 #ifdef sysV68
+    lprintf( L_NOISE, "tio_set_flow_control: using TCSETHW" );
+
     if ( type & FLOW_HARD ) {
 	if ( ioctl(fd, TCSETHW, 1) < 0 ) {
 		lprintf( L_ERROR, "ioctl TCSETHW on failed" );
@@ -950,3 +962,42 @@ int tio_get_rs232_lines _P1( (fd), int fd)
     }
     return flags;
 }
+
+/* tio_set_rs232_lines()
+ *
+ * set the status of the DTR and RTS RS232 status lines
+ * (coded by the TIO_F_* flags. On systems that have the BSD TIOCM_*
+ * flags, we use them, on others we may have to do some other tricks)
+ *
+ * "-1" can mean "error" or "not supported on this system" (e.g. SCO).
+ */
+
+int tio_set_rs232_lines _P3( (fd, do_dtr, do_rts), 
+				int fd, int do_dtr, int do_rts )
+{
+    int mctl, rc=0;
+
+#ifdef TIO_F_SYSTEM_DEFS
+    mctl = TIOCM_DTR;
+    if ( do_dtr != -1 &&
+         ioctl( fd, do_dtr? TIOCMBIS: TIOCMBIC, &mctl ) < 0 )
+    {
+	lprintf( L_ERROR, "tio_set_rs232_lines: %s DTR failed",
+			do_dtr? "set": "clear" );
+	rc=-1;
+    }
+
+    mctl = TIOCM_RTS;
+    if ( do_rts != -1 &&
+         ioctl( fd, do_rts? TIOCMBIS: TIOCMBIC, &mctl ) < 0 )
+    {
+	lprintf( L_ERROR, "tio_set_rs232_lines: %s RTS failed",
+			do_rts? "set": "clear" );
+	rc=-1;
+    }
+
+#else
+    lprintf( L_WARN, "setting of RS232 lines not supported" );
+#endif
+    return rc;
+}
