@@ -3,7 +3,7 @@
  *
  * Defines the structure with data and routines for the hardware drivers.
  *
- * $Id: hardware.h,v 1.4 1998/09/09 21:06:35 gert Exp $
+ * $Id: hardware.h,v 1.11 1999/06/15 12:38:22 marcs Exp $
  *
  */
 
@@ -11,6 +11,10 @@
  * Structure with voice modem hardware informations and functions
  */
 
+/* Voice modem quirks masks */
+typedef unsigned char vmq_t;
+#define VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER 1
+
 typedef struct
      {
      char *name;
@@ -40,6 +44,9 @@ typedef struct
      char *ask_mode_cmnd;
      char *ask_mode_answr;
      char *voice_mode_id;
+     char *play_dtmf_cmd;
+     char *play_dtmf_extra;
+     char *play_dtmf_answr;
      int (*answer_phone) (void);
      int (*beep) (int frequency, int duration);
      int (*dial) (char* number);
@@ -62,6 +69,8 @@ typedef struct
      int (*voice_mode_off) (void);
      int (*voice_mode_on) (void);
      int (*wait) (int timeout);
+     int (*play_dtmf) (char* number);
+     vmq_t voice_modem_quirks;
      } voice_modem_struct;
 
 /*
@@ -81,11 +90,15 @@ extern int rom_release;
 extern voice_modem_struct no_modem;
 extern voice_modem_struct Cirrus_Logic;
 extern voice_modem_struct Dolphin;
+extern voice_modem_struct Digi_RAS;
 extern voice_modem_struct Dr_Neuhaus;
 extern voice_modem_struct Elsa;
 extern voice_modem_struct IS_101;
 extern voice_modem_struct ISDN4Linux;
+extern voice_modem_struct Supra;
 extern voice_modem_struct Multitech_2834ZDXv;
+extern voice_modem_struct Multitech_5634ZBAV;
+extern voice_modem_struct Multitech_5600ZDXv;
 extern voice_modem_struct Rockwell;
 extern voice_modem_struct Sierra;
 extern voice_modem_struct UMC;
