@@ -4,7 +4,7 @@
  * This is the main header file for vgetty, vm and the pvf tools.
  * It includes other header files and defines some global variables.
  *
- * $Id: voice.h,v 1.5 1998/09/09 21:06:39 gert Exp $
+ * $Id: voice.h,v 1.9 1999/07/20 07:41:11 marcs Exp $
  *
  */
 
@@ -81,6 +81,7 @@ extern char *program_name;
 extern int voice_fd;
 extern int voice_shell_state;
 extern int voice_shell_signal;
+extern int voice_shell_linger;
 extern char voice_config_file[VOICE_BUF_LEN];
 extern char *DevID;
 extern TIO tio_save;
@@ -119,6 +120,8 @@ extern int voice_close_device(void);
 extern int voice_command(char *command, char *expected_answers);
 extern int voice_config(char *new_program_name, char *DevID);
 extern int voice_detect_modemtype(void);
+extern int voice_impersonify(void);
+extern int voice_desimpersonify(void);
 #define voice_dial(a) voice_modem->dial(a)
 extern int voice_execute_shell_script(char *shell_script,
  char **shell_options);
@@ -154,7 +157,8 @@ extern void reset_watchdog(void);
 extern int voice_faxsnd(char **name, int switchbd, int max_tries);
 extern void voice_faxrec(char * spool_in, unsigned int switchbd);
 extern int enter_fax_mode(void);
-
+#define voice_play_dtmf(a) voice_modem->play_dtmf(a)
+#define voice_modem_quirks() (voice_modem->voice_modem_quirks)
 
 #ifdef USE_VARARGS
 extern int voice_write();
@@ -195,7 +199,8 @@ extern void vgetty_rings(int *rings_wanted);
 #define NO_VOICE_FD (-1)
 
 /*
- * Possible input or output devices
+ * Possible input or output devices. For details look in
+ * contrib/Steffen_Klupsch-new-set-device-modes
  */
 
 #define NO_DEVICE           (0x0001)
@@ -206,6 +211,14 @@ extern void vgetty_rings(int *rings_wanted);
 #define INTERNAL_SPEAKER    (0x0006)
 #define LOCAL_HANDSET       (0x0007)
 
+#define DIALUP_WITH_EXT_SPEAKER              (0x0008)
+#define DIALUP_WITH_INT_SPEAKER              (0x0009)
+#define DIALUP_WITH_LOCAL_HANDSET            (0x000A)
+#define DIALUP_WITH_EXTERNAL_MIC_AND_SPEAKER (0x000B)
+#define DIALUP_WITH_INTERNAL_MIC_AND_SPEAKER (0x000C)
+
+
+
 /*
  * Voice modem answers
  */
