@@ -10,7 +10,7 @@
  *
  * Marc
  *
- * $Id: Dolphin.c,v 1.4 1998/09/09 21:07:15 gert Exp $
+ * $Id: Dolphin.c,v 1.6 1999/06/15 12:38:26 marcs Exp $
  *
  */
 
@@ -137,6 +137,9 @@ voice_modem_struct Dolphin =
      (char *) IS_101_ask_mode_cmnd,
      (char *) IS_101_ask_mode_answr,
      (char *) IS_101_voice_mode_id,
+     (char *) IS_101_play_dtmf_cmd,
+     (char *) IS_101_play_dtmf_extra,
+     (char *) IS_101_play_dtmf_answr,
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -158,5 +161,7 @@ voice_modem_struct Dolphin =
      &IS_101_switch_to_data_fax,
      &IS_101_voice_mode_off,
      &IS_101_voice_mode_on,
-     &IS_101_wait
+     &IS_101_wait,
+     &IS_101_play_dtmf,
+     0
      };
