@@ -3,7 +3,7 @@
  *
  * This file contains the Dr. Neuhaus Cybermod specific hardware stuff.
  *
- * $Id: Dr_Neuhaus.c,v 1.4 1998/09/09 21:07:15 gert Exp $
+ * $Id: Dr_Neuhaus.c,v 1.7 1999/06/15 12:38:26 marcs Exp $
  *
  */
 
@@ -130,6 +130,13 @@ static int Dr_Neuhaus_set_device (int device)
           case INTERNAL_SPEAKER:
                voice_command("AT+VLS=4", "OK");
                return(OK);
+          case INTERNAL_MICROPHONE:
+	       /* The Smarty has an INTERNAL_MICROPHONE.
+		* -- Raoul Boenisch <Raoul.Boenisch@uni-essen.de>
+		*/
+               voice_command("AT+VLS=14", "OK");
+               return(OK);
+
           };
 
      lprintf(L_WARN, "%s: Unknown output device (%d)", voice_modem_name,
@@ -166,6 +173,9 @@ voice_modem_struct Dr_Neuhaus =
      (char *) IS_101_ask_mode_cmnd,
      (char *) IS_101_ask_mode_answr,
      (char *) IS_101_voice_mode_id,
+     (char *) IS_101_play_dtmf_cmd,
+     (char *) IS_101_play_dtmf_extra,
+     (char *) IS_101_play_dtmf_answr,
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -187,5 +197,7 @@ voice_modem_struct Dr_Neuhaus =
      &IS_101_switch_to_data_fax,
      &IS_101_voice_mode_off,
      &IS_101_voice_mode_on,
-     &IS_101_wait
+     &IS_101_wait,
+     &IS_101_play_dtmf,
+     0
      };
