@@ -9,7 +9,7 @@
  * You have set port_timeout in voice.conf to a minimum of 15
  * if you use 38400 Baud
  *
- * $Id: Elsa.c,v 1.4 1998/09/09 21:07:16 gert Exp $
+ * $Id: Elsa.c,v 1.6 1999/06/15 12:38:27 marcs Exp $
  *
  */
 
@@ -209,6 +209,9 @@ voice_modem_struct Elsa =
      (char *) Elsa_ask_mode_cmnd,
      (char *) IS_101_ask_mode_answr,
      (char *) IS_101_voice_mode_id,
+     (char *) IS_101_play_dtmf_cmd,
+     (char *) IS_101_play_dtmf_extra,
+     (char *) IS_101_play_dtmf_answr,
     &IS_101_answer_phone,
     &IS_101_beep,
     &IS_101_dial,
@@ -230,5 +233,7 @@ voice_modem_struct Elsa =
     &IS_101_switch_to_data_fax,
     &IS_101_voice_mode_off,
     &IS_101_voice_mode_on,
-    &IS_101_wait
+    &IS_101_wait,
+    &IS_101_play_dtmf,
+    0
     };
