@@ -11,14 +11,14 @@
  *
  * New updated driver by Jens Adner <Jens.Adner@Wirtschaft.TU-Ilmenau.DE>.
  *
- * $Id: UMC.c,v 1.4 1998/09/09 21:07:23 gert Exp $
+ * $Id: UMC.c,v 1.7 1999/06/15 13:04:01 marcs Exp $
  *
  */
 
 #include "../include/voice.h"
 
-#define UMC_RELEASE "0.01"
-#define UMC_VTS_WORKAROUND yes
+#define UMC_RELEASE "0.02"
+// #define UMC_VTS_WORKAROUND yes
 /* #define UMC_EXTENDED_DETECTION yes */
 #define UMC_SPEAKER_ON yes
 /* workaround: it should set by vgetty
@@ -85,7 +85,7 @@ static int UMC_set_compression(int *compression, int *speed, int *bits)
      reset_watchdog();
 
      if (*compression == 0)
-          *compression = 2;
+          *compression = 4;
 
      if (*speed == 0)
           *speed = 7200;
@@ -130,6 +130,14 @@ static int UMC_set_device(int device)
 
      current_device=device;
 
+     /* Sending a ATH0 results in leaving voice mode.
+      * The UMC modem reports ERROR if an AT#VLS command is issued while not
+      * beeing in voice mode.
+      * Thus this force into voice mode.
+      * -- steffen@informatik.tu-darmstadt.de
+      */
+     voice_command("AT#CLS=8", "OK");
+
      switch (device)
           {
           case NO_DEVICE:
@@ -201,7 +209,14 @@ static int UMC_beep(int frequency, int length)
      char buffer[VOICE_BUF_LEN];
 
      reset_watchdog();
-     sprintf(buffer, "AT#VTS=[%d,0,%d]", frequency, length / 10);
+     if (length > 4000 )
+          lprintf(L_WARN, "%s->%s: Warning beeps longer than 4000 ms might not be supported.",
+	   program_name, voice_modem_name);
+
+     lprintf(L_JUNK, "%s->%s: Some UMC modems beep with fixed frequency. This is a not a software bug.",
+      program_name, voice_modem_name);
+
+     sprintf(buffer, "AT#VTS=[%d,0,%d]", frequency, length / 100);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           return(FAIL);
@@ -213,7 +228,7 @@ int UMC_switch_to_data_fax(char *mode)
      {
      char buffer[VOICE_BUF_LEN];
      reset_watchdog();
-     sprintf(buffer, "AT+FCLASS=%s", mode);
+     sprintf(buffer, "AT#CLS=%s", mode);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           return(FAIL);
@@ -263,6 +278,9 @@ voice_modem_struct UMC =
      (char *) UMC_ask_mode_cmnd,
      (char *) IS_101_ask_mode_answr,
      (char *) IS_101_voice_mode_id,
+     (char *) IS_101_play_dtmf_cmd,
+     (char *) IS_101_play_dtmf_extra,
+     (char *) IS_101_play_dtmf_answr,
      &IS_101_answer_phone,
      &UMC_beep,
      &IS_101_dial,
@@ -284,5 +302,11 @@ voice_modem_struct UMC =
      &UMC_switch_to_data_fax,
      &IS_101_voice_mode_off,
      &IS_101_voice_mode_on,
-     &IS_101_wait
+     &IS_101_wait,
+     &IS_101_play_dtmf,
+     VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER /* steffen@informatik.tu-darmstadt.de */
      };
+
+
+
+
