@@ -21,8 +21,10 @@
  * V0.4 :Moved all voice configuring commands so that they occur where they're
  *       relevant and in voice mode. Software flow control is no longer
  *       supported. b2:
+ * A very good US Robotics technical reference manual is available
+ * at: http://www.alliancedatacom.com/us-robotics-manuals.htm (not a typo).
  *
- * $Id: US_Robotics.c,v 1.4 1998/09/09 21:07:24 gert Exp $
+ * $Id: US_Robotics.c,v 1.11 1999/07/20 07:30:38 marcs Exp $
  *
  */
 
@@ -43,12 +45,14 @@ static int probed_for_adpcm = FALSE;
 static int in_adpcm_mode = FALSE;
 static int internal_speaker_used = FALSE;
 
+
+
 static int USR_beep(int frequency, int length)
      {
 
      /*
       * Ugly hack: my USRobotics SportsterFlash doesn't catch dtmf codes
-      * after a beep.  If I send it the "AT#VLS=4A" (answer phone) string
+      * after a beep.  If I send it the "AT#VLS=0A" (answer phone) string
       * after an "AT#VTS[%d,0,%d]" (beep) command it would resume detecting
       * tones
       * 
@@ -56,12 +60,27 @@ static int USR_beep(int frequency, int length)
       
      if (IS_101_beep(frequency, length) != OK)
           return(FAIL);
+
+     /*  --- "Luca Olivetti" <luca@olivetti.dhis.org>
+      *     A long time ago I introduced a workaround in US_Robotics.c to a
+      *     problem: if you sent a beep command the modem wouldn't recognize
+      *     DTMF codes afterwards.  The workaround was to send the "answer
+      *     phone" code (AT#VLS=4A).  Now I realized that this wouldn't work
+      *     if the internal or the external speaker is in use, because after
+      *     the AT#VLS=4A the modem will go off hook, effectively changing the
+      *     Thus this patch enable the workaround only if the selected device
+      *     is *not* the internal/external speaker (the modem doesn't beep
+      *     with the internal speaker anyway but at least it won't go off
+      *     hook -- it beeps with the *external* speaker though). 
+      */ 
+
+     if (internal_speaker_used) return(OK);
           
      if (IS_101_answer_phone() != VMA_OK)
           return(FAIL);
      
      return(OK);
-     } 
+} 
 
 static int USR_init(void)
      {
@@ -88,8 +107,7 @@ static int USR_init(void)
           lprintf(L_WARN, "VTD setup successful");
 
      /*
-      * Set silence threshold and length. Must be in voice mode to do this.
-      */
+      * Set silence threshold and length. Must be in voice mode to do this.  */
 
      sprintf(buffer, "AT#VSD=1#VSS=%d#VSP=%d",
       cvd.rec_silence_threshold.d.i * 3 / 100,
@@ -98,6 +116,17 @@ static int USR_init(void)
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN,"setting recording preferences didn't work");
 
+     /* -- alborchers@steinerpoint.com
+      * AT+VRA and AT+VRN - Delay after ringback or before any ringback
+      *                     before modem assumes phone has been answered.
+      */
+
+     sprintf(buffer, "AT+VRA=%d+VRN=%d",
+      cvd.ringback_goes_away.d.i, cvd.ringback_never_came.d.i);
+
+     if (voice_command(buffer, "OK") != VMA_USER_1)
+          lprintf(L_WARN,"setting ringback delay didn't work");
+
      voice_modem_state = IDLE;
      return(OK);
      }
@@ -253,6 +282,9 @@ static int USR_set_device(int device)
           case DIALUP_LINE:
                voice_command("AT#VLS=0","OK|VCON");
                return(OK);
+	  case LOCAL_HANDSET:  /* by gmilner@my-dejanews.com */
+	      voice_command("AT#VLS=1","OK|VCON");
+	      return(OK);
           case EXTERNAL_MICROPHONE:
                voice_command("AT#VLS=1","OK|VCON");
                return(OK);
@@ -261,6 +293,7 @@ static int USR_set_device(int device)
                voice_command("AT#VLS=4","OK|VCON");
                return(OK);
           case EXTERNAL_SPEAKER:
+               internal_speaker_used = TRUE;
                voice_command("AT#VLS=2","OK|VCON");
                return(OK);
           case INTERNAL_MICROPHONE:
@@ -287,7 +320,54 @@ static int USR_switch_to_data_fax (char *mode)
      return(OK);
      }
 
-static char USR_pick_phone_cmnd[] = "AT#VLS=4A";
+
+/* -- Niels Basjes <Niels@Basjes.nl>
+ * Ignore DIAL TONE when recording or playing.
+ */ 
+static int USR_handle_dle(char data) 
+   {
+   if (data == 'd' || data == 'i')
+      {
+      /* In this situation IS_101_handle_dle will create a DAIL_TONE event. */
+      /* This DLE is however incorrectly generated by the USRobotics modems */
+      /* and should be ignored when we are either PLAYING or RECORDING      */
+      switch (voice_modem_state)
+           {
+           case PLAYING:
+                lprintf(L_JUNK, "USR_handle_dle: Ignoring <DLE> <%c> because the modem is PLAYING.",data);
+                return(OK);
+           case RECORDING:
+                lprintf(L_JUNK, "USR_handle_dle: Ignoring <DLE> <%c> because the modem is RECORDING.",data);
+                return(OK);
+           }
+      }
+   
+   return(IS_101_handle_dle(data));
+   }
+
+/* -- alborchers@steinerpoint.com */
+static int USR_voice_mode_on(void)
+     {
+
+     int ret;
+     static char buffer[VOICE_BUF_LEN];
+
+
+     if( (ret=IS_101_voice_mode_on( )) != OK )
+          return( ret );
+
+     /* reset voice preferences, they are forgotten after leaving voice mode */
+     sprintf(buffer, "AT#VTD=3F,3F,3F#VSD=1#VSS=%d#VSP=%d#VRA=%d#VRN=%d",
+      cvd.rec_silence_threshold.d.i * 3 / 100, cvd.rec_silence_len.d.i,
+      cvd.ringback_goes_away.d.i, cvd.ringback_never_came.d.i);
+
+     if (voice_command(buffer, "OK") != VMA_USER_1)
+          lprintf(L_WARN,"setting voice preferences didn't work");
+
+     return(OK);
+     }
+
+static char USR_pick_phone_cmnd[] = "AT#VLS=0A"; /* -- alborchers@steinerpoint.com */
 static char USR_pick_phone_answr[] = "VCON";
 static char USR_beep_cmnd[] = "AT#VTS=[%d,0,%d]";
 #define     USR_beep_timeunit 100
@@ -332,10 +412,13 @@ voice_modem_struct US_Robotics =
      (char *) USR_ask_mode_cmnd,
      (char *) IS_101_ask_mode_answr,
      (char *) IS_101_voice_mode_id,
+     (char *) IS_101_play_dtmf_cmd,
+     (char *) IS_101_play_dtmf_extra,
+     (char *) IS_101_play_dtmf_answr,
      &IS_101_answer_phone,
      &USR_beep,
      &IS_101_dial,
-     &IS_101_handle_dle,
+     &USR_handle_dle,
      &USR_init,
      &IS_101_message_light_off,
      &IS_101_message_light_on,
@@ -352,6 +435,11 @@ voice_modem_struct US_Robotics =
      &IS_101_stop_waiting,
      &USR_switch_to_data_fax,
      &IS_101_voice_mode_off,
-     &IS_101_voice_mode_on,
-     &IS_101_wait
+     &USR_voice_mode_on,
+     &IS_101_wait,
+     &IS_101_play_dtmf,
+     0
      };
+
+
+
