@@ -3,7 +3,7 @@
  *
  * This file contains the ZyXEL 1496 specific hardware stuff.
  *
- * $Id: ZyXEL_1496.c,v 1.4 1998/09/09 21:07:25 gert Exp $
+ * $Id: ZyXEL_1496.c,v 1.7 1999/07/20 07:26:01 marcs Exp $
  *
  */
 
@@ -33,7 +33,7 @@ static int ZyXEL_1496_init (void)
 
      if (voice_command("ATS40.3=1 S40.4=1 S40.5=1 S40.6=1", "OK") !=
       VMA_USER_1)
-          lprintf(L_WARN, "coudn't initialize distinctive RING");
+          lprintf(L_WARN, "couldn't initialize distinctive RING");
 
      /*
       * ATS39.6=1 - Enable DTMF detection after AT+VLS=2
@@ -97,6 +97,17 @@ static int ZyXEL_1496_init (void)
      if (voice_command("AT+VNH=1", "OK") != VMA_USER_1)
           lprintf(L_WARN, "can't disable autohangup");
 
+     /* -- alborchers@steinerpoint.com
+      * AT+VRA and AT+VRN - Delay after ringback or before any ringback
+      *                     before modem assumes phone has been answered.
+      */
+
+     sprintf(buffer, "AT+VRA=%d+VRN=%d",
+      cvd.ringback_goes_away.d.i, cvd.ringback_never_came.d.i);
+
+     if (voice_command(buffer, "OK") != VMA_USER_1)
+          lprintf(L_WARN,"setting ringback delay didn't work");
+
      voice_modem_state = IDLE;
      return(OK);
      }
@@ -231,6 +242,9 @@ voice_modem_struct ZyXEL_1496 =
      (char *) IS_101_ask_mode_cmnd,
      (char *) IS_101_ask_mode_answr,
      (char *) IS_101_voice_mode_id,
+     (char *) IS_101_play_dtmf_cmd,
+     (char *) IS_101_play_dtmf_extra,
+     (char *) IS_101_play_dtmf_answr,
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -252,5 +266,7 @@ voice_modem_struct ZyXEL_1496 =
      &IS_101_switch_to_data_fax,
      &IS_101_voice_mode_off,
      &IS_101_voice_mode_on,
-     &IS_101_wait
+     &IS_101_wait,
+     &IS_101_play_dtmf,
+     0
      };
