@@ -4,7 +4,7 @@
  * This is the callback function for the modem to the higher level
  * routines.
  *
- * $Id: event.c,v 1.4 1998/09/09 21:07:30 gert Exp $
+ * $Id: event.c,v 1.7 1999/05/15 19:17:47 marcs Exp $
  *
  */
 
@@ -86,9 +86,16 @@ void reset_watchdog(void)
 int voice_handle_event(int event, event_data data)
      {
      int result;
+     char buffer[2];
 
-     lprintf(L_JUNK, "%s: voice_handle_event got event %s with data <%c>", program_name, event_name(event),
-      data.c);
+     buffer[0] = data.c;
+     buffer[1] = '\0';
+     lprintf(L_JUNK,
+             "%s: voice_handle_event got event %s with data <%s>",
+             program_name,
+             event_name(event),
+             data.c ? buffer
+                    : "NUL");
 
      if ((event == FAX_CALLING_TONE) && (cvd.ignore_fax_dle.d.i))
           return(OK);
@@ -168,6 +175,7 @@ int voice_handle_event(int event, event_data data)
                     case DIAL_TONE:
                     case DATA_CALLING_TONE:
                     case FAX_CALLING_TONE:
+                    case RING_DETECTED:
                          return(voice_stop_waiting());
                     };
 
@@ -180,8 +188,11 @@ int voice_handle_event(int event, event_data data)
           return(OK);
           }
 
-     lprintf(L_WARN, "%s: voice_handle_event got unknown event %s with data <%c>", program_name,
-      event_name(event), data.c);
+     buffer[0] = data.c;
+     lprintf(L_JUNK,
+             "%s: voice_handle_event got unknown event %s with data <%s>",
+             program_name, event_name(event), data.c ? buffer : "NUL");
+
      return(UNKNOWN_EVENT);
      }
 
