@@ -4,7 +4,7 @@
  * Executes the shell script given as the argument. If the argument is
  * empty, commands are read from standard input.
  *
- * $Id: shell.c,v 1.4 1998/09/09 21:07:35 gert Exp $
+ * $Id: shell.c,v 1.8 1999/07/20 07:41:08 marcs Exp $
  *
  */
 
@@ -12,6 +12,7 @@
 
 static int events_to_shell = FALSE;
 int voice_shell_state = OFF_LINE;
+int voice_shell_linger = 0;
 static int voice_shell_input_fd = NO_VOICE_FD;
 static int voice_shell_output_fd = NO_VOICE_FD;
 static int child_pid = 0;
@@ -200,6 +201,7 @@ int voice_shell_handle_event(int event, event_data data)
      if (event == SIGNAL_SIGCHLD)
           {
           voice_shell_state = OFF_LINE;
+          voice_shell_linger = 0;
           voice_stop_current_action();
           return(OK);
           };
@@ -241,6 +243,7 @@ int voice_shell_handle_event(int event, event_data data)
                          case PLAYING:
                          case RECORDING:
                          case WAITING:
+                              voice_shell_linger = 0;
                               voice_stop_current_action();
                               break;
                          case IDLE:
@@ -299,6 +302,8 @@ int voice_shell_handle_event(int event, event_data data)
                          voice_set_device(EXTERNAL_MICROPHONE);
                     else if (strcmp(device, "INTERNAL_SPEAKER") == 0)
                          voice_set_device(INTERNAL_SPEAKER);
+                    else if (strcmp(device, "EXTERNAL_SPEAKER") == 0)
+                         voice_set_device(EXTERNAL_SPEAKER);
                     else if (strcmp(device, "LOCAL_HANDSET") == 0)
                          voice_set_device(LOCAL_HANDSET);
                     else if (voice_write_shell("ERROR") != OK)
@@ -351,6 +356,17 @@ int voice_shell_handle_event(int event, event_data data)
                     if (voice_write_shell("READY") != OK)
                          return(FAIL);
 
+                    }
+               /* -- alborchers@steinerpoint.com */
+               else if (strcmp(buffer, "GET MODEM") == 0)
+                    {
+
+                    if (voice_write_shell(voice_modem_name) != OK)
+                         return(FAIL);
+
+                    if (voice_write_shell("READY") != OK)
+                         return(FAIL);
+
                     }
                else if (strcmp(buffer, "AUTOSTOP ON") == 0)
                     {
@@ -438,7 +454,8 @@ int voice_shell_handle_event(int event, event_data data)
                     {
                     char name[VOICE_BUF_LEN] = "";
 
-                    sscanf(buffer, "%*s %s", name);
+                    voice_shell_linger = 0; /* -- alborchers@steinerpoint.com */
+                    sscanf(buffer, "%*s %s %d", name, &voice_shell_linger);
 
                     if (strlen(name) != 0)
                          {
@@ -460,6 +477,8 @@ int voice_shell_handle_event(int event, event_data data)
 
                          }
 
+                    voice_shell_linger = 0;
+
                     if (voice_write_shell("READY") != OK)
                          return(FAIL);
 
@@ -512,6 +531,24 @@ int voice_shell_handle_event(int event, event_data data)
                          return(FAIL);
 
                     }
+               else if (strncmp(buffer, "DTMF", 4) == 0)
+                    {
+                    char number[VOICE_BUF_LEN] = "";
+
+                    sscanf(buffer, "%*s %s", number);
+
+                    if (voice_write_shell("DTMFING") != OK)
+                         return(FAIL);
+
+                    if (voice_play_dtmf(number) == FAIL)
+
+                         if (voice_write_shell("ERROR") != OK)
+                              return(FAIL);
+
+                    if (voice_write_shell("READY") != OK)
+                         return(FAIL);
+
+                    } 
                else
                     {
 
@@ -531,9 +568,11 @@ int voice_shell_handle_event(int event, event_data data)
 
           switch (voice_modem_state)
                {
+               case WAITING:
+                    if( voice_shell_linger > 0 )
+                        break;
                case PLAYING:
                case RECORDING:
-               case WAITING:
                     lprintf(L_JUNK, "%s: stopping current action", program_name);
                     voice_stop_current_action();
                     break;
