@@ -4,7 +4,7 @@
  * pvfreverse reverses the voice file (it plays it from end to start).
  * Input and output is in the pvf (portable voice format) format.
  *
- * $Id: pvfreverse.c,v 1.4 1998/09/09 21:07:49 gert Exp $
+ * $Id: pvfreverse.c,v 1.5 1999/03/16 09:59:24 marcs Exp $
  *
  */
 
@@ -116,9 +116,11 @@ int main (int argc, char *argv[])
           exit(ERROR);
           }
 
-     while (!feof(fd_in))
+     while (1)
           {
           data = header_in.read_pvf_data(fd_in);
+          if (feof(fd_in))
+               break;
 
           if (voice_samples >= buffer_size)
                {
