@@ -1,7 +1,7 @@
 /*
  * answer.c
  *
- * $Id: answer.c,v 1.6 1998/09/09 21:08:05 gert Exp $
+ * $Id: answer.c,v 1.12 1999/06/27 14:29:03 marcs Exp $
  *
  */
 
@@ -35,7 +35,12 @@ static int enter_data_fax_mode(int answer_mode)
      if (modem_type == Mt_class2)
           {
           bit_order = 0;
-          fax_mode = "2";
+	  /* following the specs, we should go to +FCLASS=2;+FAA=1, but
+	   * there is a fair number of Rockwell modems that can't do
+	   * data calls if in that mode - must go to +FCLASS=0;+FAA=1 -
+	   * but yet other modems NEED class 2, so use modem_quirks...
+	   */
+          fax_mode = ( modem_quirks & MQ_NEED2 ) ? "2": "0";
           };
 
      if (modem_type == Mt_class2_0)
@@ -279,8 +284,6 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
      time_t call_start;
      time_t call_end;
      time_t call_length;
-     uid_t uid;
-     gid_t gid;
      char greeting_message[VOICE_BUF_LEN];
      char receive_dir[VOICE_BUF_LEN];
      char message[VOICE_BUF_LEN];
@@ -288,6 +291,8 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
      char *ring_type = "ring";
      int result;
 
+     setup_environment(); /* caller ID, called ID and stuff */
+
      /*
       * Mapping from mgetty's answer mode detection to the new vgetty way
       */
@@ -352,12 +357,13 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
           exit(99);
           }
 
-     if (voice_set_device(DIALUP_LINE) == FAIL)
-          {
-          lprintf(L_WARN, "%s: Could not switch to dialup line",
-           program_name);
-          exit(99);
-          }
+     if (voice_modem_quirks() & VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER) {
+       if (voice_set_device(DIALUP_LINE) == FAIL) {
+	 lprintf(L_WARN, "%s: Could not switch to dialup line",
+		 program_name);
+	 exit(99);
+       }
+     }
 
      if ((result = voice_answer_phone()) == VMA_CONNECT)
           {
@@ -366,6 +372,14 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
           return(VMA_CONNECT);
           }
 
+     if (!(voice_modem_quirks() & VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER)) {
+       if (voice_set_device(DIALUP_LINE) == FAIL) {
+	   lprintf(L_WARN, "%s: Could not switch to dialup line",
+		   program_name);
+	   exit(99);
+	 }
+     }
+
      if (result == VMA_ERROR)
           {
           lprintf(L_WARN, "%s: Could not answer the phone. Strange...",
@@ -634,7 +648,12 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
 
      time(&call_start);
 
-     if (voice_record_file(message) == FAIL)
+     if (cvd.rec_max_len.d.i == 0) {
+       lprintf(L_NOISE,
+	       "%s: skipping message recording",
+	       program_name);
+     }
+     else if (voice_record_file(message) == FAIL)
           {
           lprintf(L_WARN, "%s: Could not record a message",
            program_name);
@@ -643,25 +662,10 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
 
      time(&call_end);
      call_length = call_end - call_start;
-     get_ugid((char *) &cvd.phone_owner, (char *) &cvd.phone_group, &uid,
-      &gid);
-
-     /*
-      * change file mode 
-      */
-
-     if ((cvd.phone_mode.d.i != -1) && (chmod(message, cvd.phone_mode.d.i) !=
-      0))
-          lprintf(L_WARN, "%s: cannont change file mode", program_name);
-
      /* 
-      * change file owner and group 
+      * change file owner, group and mode done by function
       */
 
-     if (chown(message, (uid_t) uid, (gid_t) gid) != 0)
-          lprintf(L_WARN, "%s: cannot change owner and/or group",
-           program_name);
-
      if ((cvd.rec_min_len.d.i != 0) && (call_length <= cvd.rec_min_len.d.i))
           switch_to_data_fax_mode = TRUE;
 
